@@ -1,4 +1,5 @@
-/* Copyright (c) 2005-2023 Jay Berkenbilt
+/* Copyright (c) 2005-2021 Jay Berkenbilt
+ * Copyright (c) 2022-2025 Jay Berkenbilt and Manfred Holger
  *
  * This file is part of qpdf.
  *
@@ -25,9 +26,14 @@
 
 /* The first version of qpdf to include the version constants is 10.6.0. */
 #define QPDF_MAJOR_VERSION 11
-#define QPDF_MINOR_VERSION 6
+#define QPDF_MINOR_VERSION 10
 #define QPDF_PATCH_VERSION 1
-#define QPDF_VERSION "11.6.1"
+
+#ifdef QPDF_FUTURE
+# define QPDF_VERSION "11.10.1+future"
+#else
+# define QPDF_VERSION "11.10.1"
+#endif
 
 /*
  * This file defines symbols that control the which functions,
